%%% This script shows an example of how to run the PSO + fmincon.m routine
% to find IMSPE-optimal simulator-only designs


%% Example: IMSPE-optimal simulator-only design

% Clean work space
clear all
close all
format compact
format shortG 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% User-Specified Section %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Only change items in this section! %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% state design size 
n = 10;     %number of simulator runs
d = 2;      %number of simulator inputs
% (resulting IMSPE-optimal design matrix will be of size (n \times d)

% state point-prior for correlation parameters in (1 \times d) row vector
rho = [0.75, 0.75];

% state number of PSO desgins (particles) and iterations to be used
Ndes = n*d*4;	%number of designs (particles)
Nits = Ndes*2;	%number of iterations

% state identification name to be used to save files
id = 'example';

% add path where IMSPE functions live
yourpath = '../software';
if exist(yourpath,'dir')
 addpath(yourpath)
 disp(' ' )
 disp(['PATH ', yourpath,' ADDED'])
else
end
clear yourpath	

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% construct design
[ PSO_ex1, fmin_ex1] = IMSPEopt_simulator(n, d, rho, Ndes, Nits, id);
    
%%% save results
save(strcat('out_',id))

%%% see results
% simulator design
sprintf('The resulting (%d x %d) IMSPE-optimal simulator design matrix is:',n,d)
fmin_ex1.Xbest

% IMSPE value
sprintf('The IMSPE value for the resulting design is %d', fmin_ex1.IMSPE)

% calculation times
sprintf(strcat('The total (PSO + fmincon) calculation time to find',...
    ' this design was %d seconds.'),PSO_ex1.PSOtime + fmin_ex1.fmintime)




    




