function [ mx ] = S2(X,theta)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% S2:
% This function is used within the IMSE.m code to compute the integral of 
% the squared Gaussian Correlation function.
%
% Authors: Erin Leatherman, West Virginia University
%
% Questions/Comments: 
% Please email Erin Leatherman at erleatherman@mail.wvu.edu.
%
% Copyright 2016. Erin Leatherman, West Virginia University.
%
% THERE IS NO WARRANTY, EXPRESS OR IMPLIED. WE DO NOT ASSUME ANY LIABILITY
% FOR THE USE OF THIS SOFTWARE.  If software is modified to produce
% derivative works, such modified software should be clearly marked.
% Additionally, this program is free software; you can redistribute it 
% and/or modify it under the terms of the GNU General Public License as 
% published by the Free Software Foundation; version 2.0 of the License. 
% Accordingly, this program is distributed in the hope that it will be 
% useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
% of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
% General Public License for more details.
%
% For function details and reference information, see:
% http://stat.wvu.edu/~erl/CompExpDesgs_Pred/designs/
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INPUTS:
% X = nxp matrix of design points, where 
%       n=number of design points
%       p=number of input variables corresponding to correlations theta~=0
% theta = 1xp row vector of correlation parameters, where theta=-4*log(rho)
%       and theta~=0; 
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUTPUT: 
% mx = nxn matrix of p-dimensional integrals of the squared Gaussian
%       Correlation function
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% REQUIRED FUNCTION: S1_0.m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[Si Sj]=meshgrid(1:size(X,1),1:size(X,1));
X1 = X(Si,:);
X2 = X(Sj,:);


mx=reshape(...
    prod(exp(bsxfun(@times,(X1-X2).^2,-.5*theta)).*S1_0((X1+X2)/2,2*theta),2),...
    sqrt(size(X1,1)),sqrt(size(X1,1)));


end