function [ Ival ] = vect_IMSE( X )

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% vect_IMSE:
% This function is used within the PSO_IMSPE_Sim.m code.  It reshapes an 
% nd x 1  vector of design points into a n x d design matrix and determines
% if any of the points are within a distance of 10^(-3) of each other. If
% the points are not with this distance of each other, the IMSPE is 
% calculated for the design.
%
% Author: Erin Leatherman, West Virginia University
%
% Questions/Comments: 
% Please email Erin Leatherman at erleatherman@mail.wvu.edu.
%
% Copyright 2016. Erin Leatherman, West Virginia University.
%
% THERE IS NO WARRANTY, EXPRESS OR IMPLIED. WE DO NOT ASSUME ANY LIABILITY
% FOR THE USE OF THIS SOFTWARE.  If software is modified to produce
% derivative works, such modified software should be clearly marked.
% Additionally, this program is free software; you can redistribute it 
% and/or modify it under the terms of the GNU General Public License as 
% published by the Free Software Foundation; version 2.0 of the License. 
% Accordingly, this program is distributed in the hope that it will be 
% useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
% of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
% General Public License for more details.
%
% For function details and reference information, see:
% http://stat.wvu.edu/~erl/CompExpDesgs_Pred/designs/
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INPUTS:
% X = nd x 1 vector of design points
%
% GLOBAL INPUTS:
% sdraws = 1xd row vector of correlation parameters
% nglob = number of simulator runs
% dglob = number of input dimensions
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUTPUTS: 
% Ival = (1/\sigma_Z^2) \times the integrated mean squared prediction
%      error of the BLUP (for the GP(\beta, \sigma_Z^2,\rho_vector) 
%      stochastic model)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Required Functions: IMSE.m, S1_0.m, S2.m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


global sdraws nglob dglob

X = reshape(X, nglob, dglob);


if min(pdist(X)) <= 10^(-3)
        Ival=999999;
else


Ival = IMSE(X,sdraws);
end

end

